/*
 * Created on Oct 6, 2004
 * 
 * Copyright 2004 Harshy Wanigasekara
 * This software distributed under the terms of the GNU Public license.
 * See the accompanying file COPYING.txt for complete information.
 *
 * Base class for tip calc states
 * 
 */

import javax.microedition.lcdui.*;

/**
 * @author harshy
 * @version 1.0
 * 
 * This is the base class for the tip calculator state
 * machine.
 * 
 * @see TipStateMachine
 */
public class TipCalcState implements CommandListener
{
	/**
	 * Reference to the midlet object, used to signal
	 * exit.
	 */
	final TipCalc	midlet;
	
	/**
	 * Reference to the state machine.  Used to switch to
	 * next or previous state.
	 */
	TipStateMachine	state;
	
	/**
	 * The screen associated with states.
	 */
	Screen			stateScreen;
	
	/**
	 * Set references to the main midlet and state machine.
	 * 
	 * @param main Reference to midlet.
	 * @param mach Reference to state machine.
	 */
	public TipCalcState(TipCalc main, TipStateMachine mach)
	{
		midlet = main;
		state = mach;
	}

	/**
	 * Cause the screen associated with this state to
	 * be displayed.
	 */
	public void showScreen()
	{
		Display.getDisplay(midlet).setCurrent(stateScreen);
	}

	/**
	 * Handle generic commands from screens.
	 */
	public void commandAction(Command c, Displayable d)
	{
		if (c.getCommandType() == Command.EXIT)
		{
			midlet.exitRequested();
		}
		else if (c.getCommandType() == Command.OK)
		{
			state.nextState();
		}
		else if (c.getCommandType() == Command.BACK)
		{
			state.prevState();
		}
	}

	/**
	 * Update the displayed values on the screen.  Does nothing in base class.
	 */
	public void updateValues()
	{
	}
}
