/*
 * Created on Oct 6, 2004
 * 
 * Copyright 2004 Harshy Wanigasekara
 * This software distributed under the terms of the GNU Public license.
 * See the accompanying file COPYING.txt for complete information.
 *
 * Contains the state machine for the Tip Calculator app.
 */

import java.util.Vector;

/**
 * @author harshy
 * @version 1.0
 *
 * The main state machine for the Tip Calculator app.
 * Handles moving between states, and triggering screen
 * updates.
 * 
 * @see TipCalcState
 * @see TipCalc
 */
public class TipStateMachine
{
	/**
	 * Current state.
	 */
	private int		currentState;
	
	/**
	 * The states.
	 */
	private Vector states;

	/**
	 * Initialize state to 0, the first one.
	 * Also create the state objects.
	 * 
	 * @param main Reference to MIDlet object.
	 */
	public TipStateMachine(TipCalc main)
	{
		currentState = 0;

		states = new Vector();
		states.addElement(new TitleState(main, this));
		states.addElement(new GetPriceState(main, this));
		states.addElement(new GetPeopleState(main, this));
		states.addElement(new ShowResultState(main, this));
	}
	
	/**
	 * Move to the next state.
	 */
	public void nextState()
	{
		if (currentState < (states.size() - 1))
		{
			currentState++;
			displayState();
		}
	}
	
	/**
	 * Move to previous state.
	 */
	public void prevState()
	{
		if (currentState > 0)
		{
			currentState--;
			displayState();
		}
	}
	
	/**
	 * Cause the screen associated with the current
	 * state to be displayed.
	 */
	public void displayState()
	{
		if ((currentState <0) || (currentState >= states.size()))
		{
			// system.out.println("bad state");
		}
		else
		{
			TipCalcState nowState = (TipCalcState) states.elementAt(currentState);
			nowState.updateValues();
			nowState.showScreen();
		}
	}
}
